searchData={"content_type":"text/markdown","items":[{"doc":"QRex is a high-performance QR code detection and decoding library.\n\nThis module provides functionality to detect and decode QR codes from image data\nusing Rust-based NIFs (Native Implemented Functions).","ref":"QRex.html","title":"QRex","type":"module"},{"doc":"# Detect QR codes in an image\n    image_bytes = File.read!(\"qr_code.png\")\n    {:ok, decoded_codes} = QRex.detect_qr_codes(image_bytes)\n\nThe library supports precompiled NIFs for various platforms and will automatically\nuse the appropriate version for your system.","ref":"QRex.html#module-usage","title":"Usage - QRex","type":"module"},{"doc":"The detection function returns results in the following format:\n  * `{:ok, [{:ok, qr_code}, ...]}` - Successful detection with decoded QR codes\n  * `{:ok, [{:error, reason}, ...]}` - Successful detection with some decode errors\n  * `{:error, reason}` - Failed to process the image","ref":"QRex.html#module-error-handling","title":"Error Handling - QRex","type":"module"},{"doc":"* `RUSTLER_PRECOMPILATION_QREX_BUILD` - Set to \"1\" or \"true\" to force building from source","ref":"QRex.html#module-environment-variables","title":"Environment Variables - QRex","type":"module"},{"doc":"Detects and decodes QR codes in the provided image data.\n\nTakes raw image bytes as input and attempts to locate and decode any QR codes\npresent in the image.","ref":"QRex.html#detect_qr_codes/1","title":"QRex.detect_qr_codes/1","type":"function"},{"doc":"* `image_bytes` - Binary data of the image file","ref":"QRex.html#detect_qr_codes/1-parameters","title":"Parameters - QRex.detect_qr_codes/1","type":"function"},{"doc":"* `{:ok, codes}` where `codes` is a list of results:\n    * `{:ok, qr_code}` for successfully decoded QR codes\n    * `{:error, reason}` for QR codes that couldn't be decoded\n  * `{:error, reason}` if image processing fails","ref":"QRex.html#detect_qr_codes/1-returns","title":"Returns - QRex.detect_qr_codes/1","type":"function"},{"doc":"iex> image_data = File.read!(\"test.png\")\n    iex> {:ok, results} = QRex.detect_qr_codes(image_data)\n    iex> results\n    [{:ok, %QRex.QRCode{text: \"Hello!\", version: 1, ...}}]","ref":"QRex.html#detect_qr_codes/1-examples","title":"Examples - QRex.detect_qr_codes/1","type":"function"},{"doc":"Represents the decoded data and metadata of a QR code.\n\nThis struct contains all the essential information extracted from a QR code,\nincluding its content, version, size, error correction level, and position\nin the image.","ref":"QRex.QRCode.html","title":"QRex.QRCode","type":"module"},{"doc":"* `:text` - The decoded textual content of the QR code\n  * `:version` - QR code version number (1-40)\n  * `:modules` - Size of the QR code in modules (21-177)\n  * `:ecc_level` - Error correction level (0-3)\n  * `:bounds` - List of four coordinate pairs representing the QR code's corners","ref":"QRex.QRCode.html#module-fields","title":"Fields - QRex.QRCode","type":"module"},{"doc":"%QRex.QRCode{\n      text: \"Hello, World!\",\n      version: 1,\n      modules: 21,\n      ecc_level: 0,\n      bounds: [{10, 10}, {31, 10}, {31, 31}, {10, 31}]\n    }","ref":"QRex.QRCode.html#module-examples","title":"Examples - QRex.QRCode","type":"module"},{"doc":"QR code data structure.\n\nContains the following fields:\n  * `:text` - The textual content of the QR code\n  * `:version` - The version of the QR code (1-40)\n  * `:modules` - The number of modules in the QR code (21-177)\n  * `:ecc_level` - The error correction level (0-3)\n  * `:bounds` - The four boundary points of the QR code as coordinate pairs","ref":"QRex.QRCode.html#t:t/0","title":"QRex.QRCode.t/0","type":"type"},{"doc":"# QRex\n\n[![Hex.pm](https://img.shields.io/hexpm/v/qrex.svg)](https://hex.pm/packages/qrex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/qrex)\n[![License](https://img.shields.io/hexpm/l/qrex.svg)](https://github.com/brandonhamilton/qrex/blob/master/LICENSE)\n\nQRex is a high-performance QR code detection and decoding library for Elixir, powered by Rust NIFs.","ref":"readme.html","title":"QRex","type":"extras"},{"doc":"- Fast QR code detection and decoding\n- Support for multiple QR codes in a single image\n- Pre-compiled NIFs for major platforms\n- Simple, straightforward API\n- Detailed error reporting","ref":"readme.html#features","title":"Features - QRex","type":"extras"},{"doc":"Add `qrex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:qrex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - QRex","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - QRex","type":"extras"},{"doc":"```elixir\n# Read an image file\nimage_bytes = File.read!(\"path/to/image.png\")\n\n# Detect and decode QR codes\ncase QRex.detect_qr_codes(image_bytes) do\n  {:ok, results} ->\n    # Process each detected QR code\n    Enum.each(results, fn\n      {:ok, qr_code} ->\n        IO.puts \"Found QR code: #{qr_code.text}\"\n        IO.puts \"Version: #{qr_code.version}\"\n        IO.puts \"Bounds: #{inspect(qr_code.bounds)}\"\n      \n      {:error, reason} ->\n        IO.puts \"Failed to decode QR code: #{reason}\"\n    end)\n    \n  {:error, reason} ->\n    IO.puts \"Failed to process image: #{reason}\"\nend\n```","ref":"readme.html#basic-example","title":"Basic Example - QRex","type":"extras"},{"doc":"The decoded QR code struct (`QRex.QRCode`) contains:\n\n- `text` - The decoded content\n- `version` - QR code version (1-40)\n- `modules` - Size in modules (21-177)\n- `ecc_level` - Error correction level (0-3)\n- `bounds` - Corner coordinates as `[{x, y}, ...]`","ref":"readme.html#qr-code-information","title":"QR Code Information - QRex","type":"extras"},{"doc":"QRex provides pre-compiled NIFs for:\n\n- Linux (x86_64, aarch64)\n- macOS (x86_64, arm64)\n- Windows (x86_64)\n\nFor other platforms, the library will attempt to compile from source. You'll need:\n\n- Rust toolchain (1.79.0 or later)\n- C compiler\n- Development headers","ref":"readme.html#platform-support","title":"Platform Support - QRex","type":"extras"},{"doc":"To force building from source, set the environment variable:\n\n```bash\nexport RUSTLER_PRECOMPILATION_QREX_BUILD=1\nmix deps.compile qrex --force\n```","ref":"readme.html#building-from-source","title":"Building from Source - QRex","type":"extras"},{"doc":"QRex is designed for high performance, leveraging Rust's speed and safety features:\n\n- Fast image processing algorithms\n- Zero-copy data handling where possible\n- Efficient memory management","ref":"readme.html#performance","title":"Performance - QRex","type":"extras"},{"doc":"Licensed under:\n\n- MIT license ([LICENSE](LICENSE))\n\n---","ref":"readme.html#license","title":"License - QRex","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2024 Brandon Hamilton\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}